@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: psmeca.c 10382 2017-04-03 09:14:47Z pwessel $
+ *    $Id: psmeca.c 10402 2018-01-01 19:00:52Z pwessel $
  *
- *    Copyright (c) 1996-2017 by G. Patau
+ *    Copyright (c) 1996-2018 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -781,6 +781,11 @@ Definition of scalar moment.
             moment.exponent = meca.moment.exponent;
             size = (computed_mw(moment, meca.magms) / 5.) * scale;
 
+	    if (size < 0.0) {	/* Addressing Bug #1171 */
+		fprintf (stderr,"%s: WARNING: skipping negative symbol size %g for record # %d.\n", GMT_program, size, (int)n_rec);
+		continue;
+	    }
+
             get_trans(xy[0], xy[1], &t11, &t12, &t21, &t22);
             delaz = atan2d(t12,t11);
 
